==> eog-2.28.2-i486-1gsb.txz: install/doinst.sh <==
( cd usr/share/gnome/help/eog/en_GB/figures ; rm -rf eog_save_as_window.png )
( cd usr/share/gnome/help/eog/en_GB/figures ; ln -sf ../../C/figures/eog_save_as_window.png eog_save_as_window.png )
( cd usr/share/gnome/help/eog/en_GB/figures ; rm -rf eog_start_window.png )
( cd usr/share/gnome/help/eog/en_GB/figures ; ln -sf ../../C/figures/eog_start_window.png eog_start_window.png )
( cd usr/share/gnome/help/eog/en_GB/figures ; rm -rf eog_toolbar_editor_window.png )
( cd usr/share/gnome/help/eog/en_GB/figures ; ln -sf ../../C/figures/eog_toolbar_editor_window.png eog_toolbar_editor_window.png )
( cd usr/share/gnome/help/eog/el/figures ; rm -rf eog_save_as_window.png )
( cd usr/share/gnome/help/eog/el/figures ; ln -sf ../../C/figures/eog_save_as_window.png eog_save_as_window.png )
( cd usr/share/gnome/help/eog/ja/figures ; rm -rf eog_save_as_window.png )
( cd usr/share/gnome/help/eog/ja/figures ; ln -sf ../../C/figures/eog_save_as_window.png eog_save_as_window.png )
( cd usr/share/gnome/help/eog/ja/figures ; rm -rf eog_toolbar_editor_window.png )
( cd usr/share/gnome/help/eog/ja/figures ; ln -sf ../../C/figures/eog_toolbar_editor_window.png eog_toolbar_editor_window.png )
( cd usr/share/gnome/help/eog/it/figures ; rm -rf eog_toolbar_editor_window.png )
( cd usr/share/gnome/help/eog/it/figures ; ln -sf ../../C/figures/eog_toolbar_editor_window.png eog_toolbar_editor_window.png )
( cd usr/share/gnome/help/eog/zh_CN/figures ; rm -rf eog_save_as_window.png )
( cd usr/share/gnome/help/eog/zh_CN/figures ; ln -sf ../../C/figures/eog_save_as_window.png eog_save_as_window.png )
( cd usr/share/gnome/help/eog/zh_CN/figures ; rm -rf eog_toolbar_editor_window.png )
( cd usr/share/gnome/help/eog/zh_CN/figures ; ln -sf ../../C/figures/eog_toolbar_editor_window.png eog_toolbar_editor_window.png )
( cd usr/share/gnome/help/eog/zh_TW/figures ; rm -rf eog_save_as_window.png )
( cd usr/share/gnome/help/eog/zh_TW/figures ; ln -sf ../../C/figures/eog_save_as_window.png eog_save_as_window.png )
( cd usr/share/gnome/help/eog/zh_TW/figures ; rm -rf eog_toolbar_editor_window.png )
( cd usr/share/gnome/help/eog/zh_TW/figures ; ln -sf ../../C/figures/eog_toolbar_editor_window.png eog_toolbar_editor_window.png )
( cd usr/share/gnome/help/eog/oc/figures ; rm -rf eog_save_as_window.png )
( cd usr/share/gnome/help/eog/oc/figures ; ln -sf ../../C/figures/eog_save_as_window.png eog_save_as_window.png )
( cd usr/share/gnome/help/eog/oc/figures ; rm -rf eog_start_window.png )
( cd usr/share/gnome/help/eog/oc/figures ; ln -sf ../../C/figures/eog_start_window.png eog_start_window.png )
( cd usr/share/gnome/help/eog/oc/figures ; rm -rf eog_toolbar_editor_window.png )
( cd usr/share/gnome/help/eog/oc/figures ; ln -sf ../../C/figures/eog_toolbar_editor_window.png eog_toolbar_editor_window.png )
( cd usr/share/gnome/help/eog/da/figures ; rm -rf eog_save_as_window.png )
( cd usr/share/gnome/help/eog/da/figures ; ln -sf ../../C/figures/eog_save_as_window.png eog_save_as_window.png )
( cd usr/share/gnome/help/eog/da/figures ; rm -rf eog_start_window.png )
( cd usr/share/gnome/help/eog/da/figures ; ln -sf ../../C/figures/eog_start_window.png eog_start_window.png )
( cd usr/share/gnome/help/eog/da/figures ; rm -rf eog_toolbar_editor_window.png )
( cd usr/share/gnome/help/eog/da/figures ; ln -sf ../../C/figures/eog_toolbar_editor_window.png eog_toolbar_editor_window.png )
( cd usr/share/gnome/help/eog/pa/figures ; rm -rf eog_save_as_window.png )
( cd usr/share/gnome/help/eog/pa/figures ; ln -sf ../../C/figures/eog_save_as_window.png eog_save_as_window.png )
( cd usr/share/gnome/help/eog/pa/figures ; rm -rf eog_start_window.png )
( cd usr/share/gnome/help/eog/pa/figures ; ln -sf ../../C/figures/eog_start_window.png eog_start_window.png )
( cd usr/share/gnome/help/eog/pa/figures ; rm -rf eog_toolbar_editor_window.png )
( cd usr/share/gnome/help/eog/pa/figures ; ln -sf ../../C/figures/eog_toolbar_editor_window.png eog_toolbar_editor_window.png )
( cd usr/share/gnome/help/eog/eu/figures ; rm -rf eog_save_as_window.png )
( cd usr/share/gnome/help/eog/eu/figures ; ln -sf ../../C/figures/eog_save_as_window.png eog_save_as_window.png )
( cd usr/share/gnome/help/eog/eu/figures ; rm -rf eog_toolbar_editor_window.png )
( cd usr/share/gnome/help/eog/eu/figures ; ln -sf ../../C/figures/eog_toolbar_editor_window.png eog_toolbar_editor_window.png )
( cd usr/share/gnome/help/eog/th/figures ; rm -rf eog_save_as_window.png )
( cd usr/share/gnome/help/eog/th/figures ; ln -sf ../../C/figures/eog_save_as_window.png eog_save_as_window.png )
( cd usr/share/gnome/help/eog/th/figures ; rm -rf eog_start_window.png )
( cd usr/share/gnome/help/eog/th/figures ; ln -sf ../../C/figures/eog_start_window.png eog_start_window.png )
( cd usr/share/gnome/help/eog/th/figures ; rm -rf eog_toolbar_editor_window.png )
( cd usr/share/gnome/help/eog/th/figures ; ln -sf ../../C/figures/eog_toolbar_editor_window.png eog_toolbar_editor_window.png )
( cd usr/share/gnome/help/eog/ru/figures ; rm -rf eog_save_as_window.png )
( cd usr/share/gnome/help/eog/ru/figures ; ln -sf ../../C/figures/eog_save_as_window.png eog_save_as_window.png )
( cd usr/share/gnome/help/eog/ru/figures ; rm -rf eog_start_window.png )
( cd usr/share/gnome/help/eog/ru/figures ; ln -sf ../../C/figures/eog_start_window.png eog_start_window.png )
( cd usr/share/gnome/help/eog/ru/figures ; rm -rf eog_toolbar_editor_window.png )
( cd usr/share/gnome/help/eog/ru/figures ; ln -sf ../../C/figures/eog_toolbar_editor_window.png eog_toolbar_editor_window.png )
( cd usr/share/gnome/help/eog/pt_BR/figures ; rm -rf eog_toolbar_editor_window.png )
( cd usr/share/gnome/help/eog/pt_BR/figures ; ln -sf ../../C/figures/eog_toolbar_editor_window.png eog_toolbar_editor_window.png )

if [ -x usr/bin/gconftool-2 ]; then
GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults"    usr/bin/gconftool-2 --makefile-install-rule    etc/gconf/schemas/eog.schemas >/dev/null 2>&1
fi
# update rarian database
if [ -x usr/bin/rarian-sk-update ]; then
  usr/bin/rarian-sk-update 1> /dev/null 2> /dev/null
fi

# update desktop entries
if [ -x usr/bin/update-desktop-database ]; then
  usr/bin/update-desktop-database 1> /dev/null 2> /dev/null
fi

# update hicolor icons
if [ -e usr/share/icons/hicolor/icon-theme.cache ]; then
        rm -f usr/share/icons/hicolor/icon-theme.cache
fi
usr/bin/gtk-update-icon-cache -f -q usr/share/icons/hicolor 1>/dev/null 2>/dev/null

# Restart gconfd-2 if running to reload new gconf settings
if ps acx | grep -q gconfd-2 ; then
        killall -HUP gconfd-2 ;
fi

==> eog-3.0.2-i486-1gsb.txz: install/doinst.sh <==
( cd usr/share/gnome/help/eog/el/figures ; rm -rf eog_save_as_window.png )
( cd usr/share/gnome/help/eog/el/figures ; ln -sf ../../C/figures/eog_save_as_window.png eog_save_as_window.png )
( cd usr/share/gnome/help/eog/zh_TW/figures ; rm -rf eog_save_as_window.png )
( cd usr/share/gnome/help/eog/zh_TW/figures ; ln -sf ../../C/figures/eog_save_as_window.png eog_save_as_window.png )
( cd usr/share/gnome/help/eog/zh_TW/figures ; rm -rf eog_toolbar_editor_window.png )
( cd usr/share/gnome/help/eog/zh_TW/figures ; ln -sf ../../C/figures/eog_toolbar_editor_window.png eog_toolbar_editor_window.png )
( cd usr/share/gnome/help/eog/it/figures ; rm -rf eog_toolbar_editor_window.png )
( cd usr/share/gnome/help/eog/it/figures ; ln -sf ../../C/figures/eog_toolbar_editor_window.png eog_toolbar_editor_window.png )
( cd usr/share/gnome/help/eog/sl/figures ; rm -rf eog_save_as_window.png )
( cd usr/share/gnome/help/eog/sl/figures ; ln -sf ../../C/figures/eog_save_as_window.png eog_save_as_window.png )
( cd usr/share/gnome/help/eog/sl/figures ; rm -rf eog_toolbar_editor_window.png )
( cd usr/share/gnome/help/eog/sl/figures ; ln -sf ../../C/figures/eog_toolbar_editor_window.png eog_toolbar_editor_window.png )
( cd usr/share/gnome/help/eog/sl/figures ; rm -rf eog_start_window.png )
( cd usr/share/gnome/help/eog/sl/figures ; ln -sf ../../C/figures/eog_start_window.png eog_start_window.png )
( cd usr/share/gnome/help/eog/oc/figures ; rm -rf eog_save_as_window.png )
( cd usr/share/gnome/help/eog/oc/figures ; ln -sf ../../C/figures/eog_save_as_window.png eog_save_as_window.png )
( cd usr/share/gnome/help/eog/oc/figures ; rm -rf eog_toolbar_editor_window.png )
( cd usr/share/gnome/help/eog/oc/figures ; ln -sf ../../C/figures/eog_toolbar_editor_window.png eog_toolbar_editor_window.png )
( cd usr/share/gnome/help/eog/oc/figures ; rm -rf eog_start_window.png )
( cd usr/share/gnome/help/eog/oc/figures ; ln -sf ../../C/figures/eog_start_window.png eog_start_window.png )
( cd usr/share/gnome/help/eog/pt_BR/figures ; rm -rf eog_toolbar_editor_window.png )
( cd usr/share/gnome/help/eog/pt_BR/figures ; ln -sf ../../C/figures/eog_toolbar_editor_window.png eog_toolbar_editor_window.png )
( cd usr/share/gnome/help/eog/th/figures ; rm -rf eog_save_as_window.png )
( cd usr/share/gnome/help/eog/th/figures ; ln -sf ../../C/figures/eog_save_as_window.png eog_save_as_window.png )
( cd usr/share/gnome/help/eog/th/figures ; rm -rf eog_toolbar_editor_window.png )
( cd usr/share/gnome/help/eog/th/figures ; ln -sf ../../C/figures/eog_toolbar_editor_window.png eog_toolbar_editor_window.png )
( cd usr/share/gnome/help/eog/th/figures ; rm -rf eog_start_window.png )
( cd usr/share/gnome/help/eog/th/figures ; ln -sf ../../C/figures/eog_start_window.png eog_start_window.png )
( cd usr/share/gnome/help/eog/pa/figures ; rm -rf eog_save_as_window.png )
( cd usr/share/gnome/help/eog/pa/figures ; ln -sf ../../C/figures/eog_save_as_window.png eog_save_as_window.png )
( cd usr/share/gnome/help/eog/pa/figures ; rm -rf eog_toolbar_editor_window.png )
( cd usr/share/gnome/help/eog/pa/figures ; ln -sf ../../C/figures/eog_toolbar_editor_window.png eog_toolbar_editor_window.png )
( cd usr/share/gnome/help/eog/pa/figures ; rm -rf eog_start_window.png )
( cd usr/share/gnome/help/eog/pa/figures ; ln -sf ../../C/figures/eog_start_window.png eog_start_window.png )
( cd usr/share/gnome/help/eog/ru/figures ; rm -rf eog_save_as_window.png )
( cd usr/share/gnome/help/eog/ru/figures ; ln -sf ../../C/figures/eog_save_as_window.png eog_save_as_window.png )
( cd usr/share/gnome/help/eog/ru/figures ; rm -rf eog_toolbar_editor_window.png )
( cd usr/share/gnome/help/eog/ru/figures ; ln -sf ../../C/figures/eog_toolbar_editor_window.png eog_toolbar_editor_window.png )
( cd usr/share/gnome/help/eog/ru/figures ; rm -rf eog_start_window.png )
( cd usr/share/gnome/help/eog/ru/figures ; ln -sf ../../C/figures/eog_start_window.png eog_start_window.png )
( cd usr/share/gnome/help/eog/eu/figures ; rm -rf eog_save_as_window.png )
( cd usr/share/gnome/help/eog/eu/figures ; ln -sf ../../C/figures/eog_save_as_window.png eog_save_as_window.png )
( cd usr/share/gnome/help/eog/eu/figures ; rm -rf eog_toolbar_editor_window.png )
( cd usr/share/gnome/help/eog/eu/figures ; ln -sf ../../C/figures/eog_toolbar_editor_window.png eog_toolbar_editor_window.png )
( cd usr/share/gnome/help/eog/zh_CN/figures ; rm -rf eog_save_as_window.png )
( cd usr/share/gnome/help/eog/zh_CN/figures ; ln -sf ../../C/figures/eog_save_as_window.png eog_save_as_window.png )
( cd usr/share/gnome/help/eog/da/figures ; rm -rf eog_save_as_window.png )
( cd usr/share/gnome/help/eog/da/figures ; ln -sf ../../C/figures/eog_save_as_window.png eog_save_as_window.png )
( cd usr/share/gnome/help/eog/da/figures ; rm -rf eog_toolbar_editor_window.png )
( cd usr/share/gnome/help/eog/da/figures ; ln -sf ../../C/figures/eog_toolbar_editor_window.png eog_toolbar_editor_window.png )
( cd usr/share/gnome/help/eog/da/figures ; rm -rf eog_start_window.png )
( cd usr/share/gnome/help/eog/da/figures ; ln -sf ../../C/figures/eog_start_window.png eog_start_window.png )
( cd usr/share/gnome/help/eog/en_GB/figures ; rm -rf eog_save_as_window.png )
( cd usr/share/gnome/help/eog/en_GB/figures ; ln -sf ../../C/figures/eog_save_as_window.png eog_save_as_window.png )
( cd usr/share/gnome/help/eog/en_GB/figures ; rm -rf eog_toolbar_editor_window.png )
( cd usr/share/gnome/help/eog/en_GB/figures ; ln -sf ../../C/figures/eog_toolbar_editor_window.png eog_toolbar_editor_window.png )
( cd usr/share/gnome/help/eog/en_GB/figures ; rm -rf eog_start_window.png )
( cd usr/share/gnome/help/eog/en_GB/figures ; ln -sf ../../C/figures/eog_start_window.png eog_start_window.png )

# update rarian database
if [ -x usr/bin/rarian-sk-update ]; then
  usr/bin/rarian-sk-update 1> /dev/null 2> /dev/null
fi

# update desktop entries
if [ -x usr/bin/update-desktop-database ]; then
  usr/bin/update-desktop-database 1> /dev/null 2> /dev/null
fi

# update hicolor icons
if [ -e usr/share/icons/hicolor/icon-theme.cache ]; then
        rm -f usr/share/icons/hicolor/icon-theme.cache
fi
usr/bin/gtk-update-icon-cache -f -q usr/share/icons/hicolor 1>/dev/null 2>/dev/null
